@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.26';
+$Test::BDD::Cucumber::Executor::VERSION = '0.31';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.26
+version 0.31
 
 =head1 DESCRIPTION
 
@@ -16,7 +16,6 @@ Definitions, and reporting on progress through the passed-in harness.
 =cut
 
 use Moose;
-use FindBin::libs;
 use Storable qw(dclone);
 use List::Util qw/first/;
 use List::MoreUtils qw/pairwise/;
@@ -45,38 +44,33 @@ and populates C<steps> with them.
 
 =cut
 
-has 'steps'          => ( is => 'rw', isa => 'HashRef', default => sub {{}} );
+has 'steps' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
 
 sub add_steps {
     my ( $self, @steps ) = @_;
 
     # Map the steps to be lower case...
-    for ( @steps ) {
+    for (@steps) {
         my ( $verb, $match, $code ) = @$_;
         $verb = lc $verb;
 
-        if ( $verb =~ /^(before|after)$/ )
-        {
-            $code = $match;
+        if ( $verb =~ /^(before|after)$/ ) {
+            $code  = $match;
             $match = qr//;
-        }
-        else
-        {
-            unless (ref( $match )) {
+        } else {
+            unless ( ref($match) ) {
                 $match =~ s/:\s*$//;
-                $match = quotemeta( $match );
+                $match = quotemeta($match);
                 $match = qr/^$match:?/i;
             }
         }
 
-        if ( $verb eq 'transform' or $verb eq 'after' )
-        {
+        if ( $verb eq 'transform' or $verb eq 'after' ) {
+
             # Most recently defined Transform takes precedence
             # and After blocks need to be run in reverse order
             unshift( @{ $self->{'steps'}->{$verb} }, [ $match, $code ] );
-        }
-        else
-        {
+        } else {
             push( @{ $self->{'steps'}->{$verb} }, [ $match, $code ] );
         }
 
@@ -96,31 +90,33 @@ sub execute {
     my ( $self, $feature, $harness, $tag_spec ) = @_;
     my $feature_stash = {};
 
-    $harness->feature( $feature );
-    my @background = (
-        $feature->background ? ( background => $feature->background ) : () );
+    $harness->feature($feature);
+    my @background =
+      ( $feature->background ? ( background => $feature->background ) : () );
 
     # Get all scenarios
     my @scenarios = @{ $feature->scenarios() };
 
     # Filter them by the tag spec, if we have one
     if ( defined $tag_spec ) {
-        @scenarios = $tag_spec->filter( @scenarios );
+        @scenarios = $tag_spec->filter(@scenarios);
     }
 
-    for my $scenario ( @scenarios ) {
+    for my $scenario (@scenarios) {
 
         # Execute the scenario itself
-        $self->execute_scenario({
-            @background,
-            scenario      => $scenario,
-            feature       => $feature,
-            feature_stash => $feature_stash,
-            harness       => $harness
-        });
+        $self->execute_scenario(
+            {
+                @background,
+                scenario      => $scenario,
+                feature       => $feature,
+                feature_stash => $feature_stash,
+                harness       => $harness
+            }
+        );
     }
 
-    $harness->feature_done( $feature );
+    $harness->feature_done($feature);
 }
 
 =head2 execute_scenario
@@ -150,34 +146,34 @@ the Harness interface.
 
 sub execute_scenario {
     my ( $self, $options ) = @_;
-    my (
-        $feature, $feature_stash, $harness, $outline, $background_obj,
-        $incoming_scenario_stash, $incoming_outline_stash
-    ) = @$options{
+    my ( $feature, $feature_stash, $harness, $outline, $background_obj,
+        $incoming_scenario_stash, $incoming_outline_stash )
+      = @$options{
         qw/ feature feature_stash harness scenario background scenario_stash
-        outline_stash
-        /
-    };
+          outline_stash
+          /
+      };
 
     my $is_background = $outline->background;
 
-    my $harness_start = $is_background ? 'background' : 'scenario';
+    my $harness_start = $is_background ? 'background'      : 'scenario';
     my $harness_stop  = $is_background ? 'background_done' : 'scenario_done';
 
     my $outline_stash = $incoming_outline_stash || { short_circuit => 0 };
 
     # Multiply out Scenario Outlines as appropriate
     my @datasets = @{ $outline->data };
-    @datasets = ({}) unless @datasets;
+    @datasets = ( {} ) unless @datasets;
 
     my $scenario_stash = $incoming_scenario_stash || {};
 
     my %context_defaults = (
+
         # Data portion
-        data    => '',
-        stash   => {
-            feature  => $feature_stash,
-            step     => {},
+        data  => '',
+        stash => {
+            feature => $feature_stash,
+            step    => {},
         },
 
         # Step-specific info
@@ -185,12 +181,12 @@ sub execute_scenario {
         scenario => $outline,
 
         # Communicators
-        harness  => $harness,
+        harness => $harness,
 
         transformers => $self->{'steps'}->{'transform'} || [],
     );
 
-    foreach my $dataset ( @datasets ) {
+    foreach my $dataset (@datasets) {
         my $scenario_stash = $incoming_scenario_stash || {};
         $context_defaults{stash}->{scenario} = $scenario_stash;
 
@@ -198,18 +194,19 @@ sub execute_scenario {
         $harness->$harness_start( $outline, $dataset,
             $scenario_stash->{'longest_step_line'} );
 
-        if ( not $is_background )
-        {
-            for my $before_step ( @{ $self->{'steps'}->{'before'} || [] } )
-            {
-                # Set up a context
-                my $context = Test::BDD::Cucumber::StepContext->new({
-                    %context_defaults,
-                    verb => 'before',
-                });
+        if ( not $is_background ) {
+            for my $before_step ( @{ $self->{'steps'}->{'before'} || [] } ) {
 
-                my $result = $self->dispatch( $context, $before_step,
-                        $outline_stash->{'short_circuit'} );
+                # Set up a context
+                my $context = Test::BDD::Cucumber::StepContext->new(
+                    {
+                        %context_defaults, verb => 'before',
+                    }
+                );
+
+                my $result =
+                  $self->dispatch( $context, $before_step,
+                    $outline_stash->{'short_circuit'} );
 
                 # If it didn't pass, short-circuit the rest
                 unless ( $result->result eq 'passing' ) {
@@ -220,39 +217,47 @@ sub execute_scenario {
 
         # Run the background if we have one. This recurses back in to
         # execute_scenario...
-        if ( $background_obj ) {
-            $self->execute_scenario({
-                is_background  => 1,
-                scenario       => $background_obj,
-                feature        => $feature,
-                feature_stash  => $feature_stash,
-                harness        => $harness,
-                scenario_stash => $scenario_stash,
-                outline_stash  => $outline_stash
-            });
+        if ($background_obj) {
+            $self->execute_scenario(
+                {
+                    is_background  => 1,
+                    scenario       => $background_obj,
+                    feature        => $feature,
+                    feature_stash  => $feature_stash,
+                    harness        => $harness,
+                    scenario_stash => $scenario_stash,
+                    outline_stash  => $outline_stash
+                }
+            );
         }
 
-        foreach my $step (@{ $outline->steps }) {
+        foreach my $step ( @{ $outline->steps } ) {
 
             # Multiply out any placeholders
-            my $text = $self->add_placeholders( $step->text, $dataset, $step->line );
+            my $text =
+              $self->add_placeholders( $step->text, $dataset, $step->line );
 
             # Set up a context
-            my $context = Test::BDD::Cucumber::StepContext->new({
-                %context_defaults,
+            my $context = Test::BDD::Cucumber::StepContext->new(
+                {
+                    %context_defaults,
 
-                # Data portion
-                columns => $step->columns || [],
-                data    => ref($step->data) ? dclone($step->data) : $step->data || '',
+                    # Data portion
+                    columns => $step->columns || [],
+                    data => ref( $step->data )
+                    ? dclone( $step->data )
+                    : $step->data || '',
 
-                # Step-specific info
-                step     => $step,
-                verb     => lc($step->verb),
-                text     => $text,
-            });
+                    # Step-specific info
+                    step => $step,
+                    verb => lc( $step->verb ),
+                    text => $text,
+                }
+            );
 
-            my $result = $self->find_and_dispatch( $context,
-                    $outline_stash->{'short_circuit'} );
+            my $result =
+              $self->find_and_dispatch( $context,
+                $outline_stash->{'short_circuit'} );
 
             # If it didn't pass, short-circuit the rest
             unless ( $result->result eq 'passing' ) {
@@ -261,22 +266,21 @@ sub execute_scenario {
 
         }
 
-        if ( not $is_background )
-        {
-            for my $after_step ( @{ $self->{'steps'}->{'after'} || [] } )
-            {
+        if ( not $is_background ) {
+            for my $after_step ( @{ $self->{'steps'}->{'after'} || [] } ) {
+
                 # Set up a context
-                my $context = Test::BDD::Cucumber::StepContext->new({
-                    %context_defaults,
-                    verb => 'after',
-                });
+                my $context = Test::BDD::Cucumber::StepContext->new(
+                    {
+                        %context_defaults, verb => 'after',
+                    }
+                );
 
                 # All After steps should happen, to ensure cleanup
                 my $result = $self->dispatch( $context, $after_step, 0 );
             }
         }
 
-
         $harness->$harness_stop( $outline, $dataset );
     }
 
@@ -292,12 +296,12 @@ values in the hashref, returning a string.
 
 sub add_placeholders {
     my ( $self, $text, $dataset, $line ) = @_;
-    my $quoted_text = Test::BDD::Cucumber::Util::bs_quote( $text );
+    my $quoted_text = Test::BDD::Cucumber::Util::bs_quote($text);
     $quoted_text =~ s/(<([^>]+)>)/
         exists $dataset->{$2} ? $dataset->{$2} :
             die parse_error_from_line( "No mapping to placeholder $1", $line )
     /eg;
-    return Test::BDD::Cucumber::Util::bs_unquote( $quoted_text );
+    return Test::BDD::Cucumber::Util::bs_unquote($quoted_text);
 }
 
 =head2 find_and_dispatch
@@ -315,18 +319,21 @@ sub find_and_dispatch {
     my ( $self, $context, $short_circuit ) = @_;
 
     # Short-circuit if we need to
-    return $self->skip_step($context, 'pending', "Short-circuited from previous tests")
-        if $short_circuit;
+    return $self->skip_step( $context, 'pending',
+        "Short-circuited from previous tests" )
+      if $short_circuit;
 
     # Try and find a matching step
     my $step = first { $context->text =~ $_->[0] }
-        @{ $self->{'steps'}->{$context->verb} || [] },
-        @{ $self->{'steps'}->{'step'} || [] };
+    @{ $self->{'steps'}->{ $context->verb } || [] },
+      @{ $self->{'steps'}->{'step'} || [] };
 
     # Deal with the simple case of no-match first of all
     return $self->skip_step( $context, 'undefined',
-        "No matching step definition for: " . $context->verb . ' ' . $context->text
-    ) unless $step;
+            "No matching step definition for: "
+          . $context->verb . ' '
+          . $context->text )
+      unless $step;
 
     return $self->dispatch( $context, $step, 0 );
 }
@@ -344,16 +351,17 @@ steps should be skipped.
 sub dispatch {
     my ( $self, $context, $step, $short_circuit ) = @_;
 
-    return $self->skip_step($context, 'pending', "Short-circuited from previous tests")
-        if $short_circuit;
+    return $self->skip_step( $context, 'pending',
+        "Short-circuited from previous tests" )
+      if $short_circuit;
 
     # Execute the step definition
     my ( $regular_expression, $coderef ) = @$step;
 
     # Setup what we'll pass to step_done, with out localized Test::Builder stuff
-    my $output = '';
+    my $output    = '';
     my $tb_return = {
-        output => \$output,
+        output  => \$output,
         builder => Test::Builder->create()
     };
 
@@ -363,10 +371,11 @@ sub dispatch {
     $tb_return->{'builder'}->todo_output( \$output );
 
     # Make a minumum pass
-    $tb_return->{'builder'}->ok(1, "Starting to execute step: " . $context->text );
+    $tb_return->{'builder'}
+      ->ok( 1, "Starting to execute step: " . $context->text );
 
     # Say we're about to start it up
-    $context->harness->step( $context );
+    $context->harness->step($context);
 
     # Store the string position of matches for highlighting
     my @match_locations;
@@ -383,10 +392,10 @@ sub dispatch {
 
             # Set S and C to be step-specific values before executing the step
             local *Test::BDD::Cucumber::StepFile::S = sub {
-                return $context->stash->{'scenario'}
+                return $context->stash->{'scenario'};
             };
             local *Test::BDD::Cucumber::StepFile::C = sub {
-                return $context
+                return $context;
             };
 
             # Take a copy of this. Turns out actually matching against it
@@ -395,56 +404,59 @@ sub dispatch {
             my $text = $context->text;
 
             # Save the matches
-            $context->matches([ $text =~ $regular_expression ]);
+            $context->matches( [ $text =~ $regular_expression ] );
 
             # Save the location of matched subgroups for highlighting hijinks
-            my @starts = @-; my @ends = @+;
-            @match_locations = pairwise {[$a, $b]} @starts, @ends;
+            my @starts = @-;
+            my @ends   = @+;
+            @match_locations = pairwise { [ $a, $b ] } @starts, @ends;
 
             # OK, actually execute
-            $coderef->( $context )
+            $coderef->($context);
         };
-        if ( $@ ) {
+        if ($@) {
             $Test::Builder::Test->ok( 0, "Test compiled" );
-            $Test::Builder::Test->diag( $@ );
+            $Test::Builder::Test->diag($@);
         }
 
         # Close up the Test::Builder object
         $tb_return->{'builder'}->done_testing();
 
-        my $status = $self->_test_status($tb_return->{builder});
+        my $status = $self->_test_status( $tb_return->{builder} );
 
         # Create the result object
-        $result = Test::BDD::Cucumber::Model::Result->new({
-            result => $status,
-            output => $output
-        });
+        $result = Test::BDD::Cucumber::Model::Result->new(
+            {
+                result => $status,
+                output => $output
+            }
+        );
 
     }
 
-    my @clean_matches = $self->_extract_match_strings(
-        $context->text, \@match_locations
-    );
+    my @clean_matches =
+      $self->_extract_match_strings( $context->text, \@match_locations );
     @clean_matches = [ 0, $context->text ] unless @clean_matches;
 
     # Say the step is done, and return the result. Happens outside
     # the above block so that we don't have the localized harness
     # anymore...
-    $context->harness->add_result( $result );
+    $context->harness->add_result($result);
     $context->harness->step_done( $context, $result, \@clean_matches );
     return $result;
 }
 
 sub _extract_match_strings {
-    my ($self, $text, $locations) = @_;
+    my ( $self, $text, $locations ) = @_;
 
     # Clean up the match locations
     my @match_locations = grep {
-            ( $_->[0] != $_->[1] ) && # No zero-length matches
-            # And nothing that matched the full string
-            (! (( $_->[0] == 0 ) && (( $_->[1] == length $text ) )))
-        } grep { defined $_ && ref $_ && defined $_->[0] && defined $_->[1] }
-        @$locations;
+        ( $_->[0] != $_->[1] ) &&    # No zero-length matches
+                                     # And nothing that matched the full string
+          ( !( ( $_->[0] == 0 ) && ( ( $_->[1] == length $text ) ) ) )
+      } grep {
+        defined $_ && ref $_ && defined $_->[0] && defined $_->[1]
+      } @$locations;
 
     return unless @match_locations;
 
@@ -455,17 +467,18 @@ sub _extract_match_strings {
         # Don't want a complain about numbers already in range, as that's
         # expected for nested matches
         no warnings;
-        $range->addrange($_->[0] . '..' . ($_->[1]-1) ) for @match_locations;
+        $range->addrange( $_->[0] . '..' . ( $_->[1] - 1 ) )
+          for @match_locations;
     }
 
     # Walk the string, splitting
-    my @parts = ([0,'']);
-    for ( 0 .. ((length $text) - 1) ) {
-        my $to_highlight = $range->inrange( $_ );
+    my @parts = ( [ 0, '' ] );
+    for ( 0 .. ( ( length $text ) - 1 ) ) {
+        my $to_highlight = $range->inrange($_);
         my $character = substr( $text, $_, 1 );
 
         if ( $parts[-1]->[0] != $to_highlight ) {
-            push( @parts, [$to_highlight, ''] );
+            push( @parts, [ $to_highlight, '' ] );
         }
 
         $parts[-1]->[1] .= $character;
@@ -478,39 +491,40 @@ sub _test_status {
     my $self    = shift;
     my $builder = shift;
 
-    my $results = $builder->can("history") ? $self->_test_status_from_history($builder)
-                                           : $self->_test_status_from_details($builder);
-
+    my $results =
+        $builder->can("history")
+      ? $self->_test_status_from_history($builder)
+      : $self->_test_status_from_details($builder);
 
     # Turn that in to a Result status
-    return $results->{'fail'} ? 'failing' :
-           $results->{'todo'} ? 'pending' :
-                                'passing' ;
+    return
+        $results->{'fail'} ? 'failing'
+      : $results->{'todo'} ? 'pending'
+      :                      'passing';
 }
 
 sub _test_status_from_details {
-    my $self = shift;
+    my $self    = shift;
     my $builder = shift;
 
     # Make a note of test status
     my %results = map {
         if ( $_->{'ok'} ) {
-            if ( $_->{'type'} eq 'todo' ||  $_->{'type'} eq 'todo_skip' ) {
-                ( todo => 1)
+            if ( $_->{'type'} eq 'todo' || $_->{'type'} eq 'todo_skip' ) {
+                ( todo => 1 );
             } else {
-                ( pass => 1 )
+                ( pass => 1 );
             }
         } else {
-            ( fail => 1 )
+            ( fail => 1 );
         }
     } $builder->details;
 
     return \%results;
 }
 
-
 sub _test_status_from_history {
-    my $self = shift;
+    my $self    = shift;
     my $builder = shift;
 
     my $history = $builder->history;
@@ -523,9 +537,6 @@ sub _test_status_from_history {
     return \%results;
 }
 
-
-
-
 =head2 skip_step
 
 Accepts a step-context, a result-type, and a textual reason, exercises the
@@ -537,21 +548,22 @@ sub skip_step {
     my ( $self, $context, $type, $reason ) = @_;
 
     # Pretend to start step execution
-    $context->harness->step( $context );
+    $context->harness->step($context);
 
     # Create a result object
-    my $result = Test::BDD::Cucumber::Model::Result->new({
-        result => $type,
-        output => '1..0 # SKIP ' . $reason
-    });
+    my $result = Test::BDD::Cucumber::Model::Result->new(
+        {
+            result => $type,
+            output => '1..0 # SKIP ' . $reason
+        }
+    );
 
     # Pretend we executed it
-    $context->harness->add_result( $result );
+    $context->harness->add_result($result);
     $context->harness->step_done( $context, $result );
     return $result;
 }
 
-
 =head1 AUTHOR
 
 Peter Sergeant C<pete@clueball.com>
